==> babel-upgrade-0.0.14.tgz: package/lib/bin.js <==
function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } } function _next(value) { step("next", value); } function _throw(err) { step("throw", err); } _next(); }); }; }

var path = require('path');

var _require = require('.'),
    isAcceptedNodeVersion = _require.isAcceptedNodeVersion,
    writePackageJSON = _require.writePackageJSON,
    writeBabelRC = _require.writeBabelRC,
    writeMochaOpts = _require.writeMochaOpts,
    installDeps = _require.installDeps;

var globby = require('globby');

var cwd = process.cwd();

if (!isAcceptedNodeVersion()) {
  throw new Error("Babel 7 will only support Node 4 and higher");
} // TOOD: allow passing a specific path


_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee() {
  var paths, packages, mochaOpts;
  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return globby(['**/.babelrc', '!**/node_modules/**']);

        case 2:
          paths = _context.sent;
          _context.next = 5;
          return globby(['**/package.json', '!**/node_modules/**']);

        case 5:
          packages = _context.sent;
          _context.next = 8;
          return globby(['**/mocha.opts', '!**/node_modules/**']);

        case 8:
          mochaOpts = _context.sent;

          // if not a monorepo
          if (packages.length === 1) {
            if (paths.length > 1) {
              console.log("We suggest using the new 'overrides' option instead of nested .babelrc's, can check out http://new.babeljs.io/docs/en/next/babelrc.html#overrides");
              console.log("");
            }

            paths.forEach(function (p) {
              return writeBabelRC(p);
            });
          }

          mochaOpts.forEach(function (p) {
            return writeMochaOpts(p);
          }); // TOOD: allow passing a specific path

          _context.next = 13;
          return writePackageJSON();

        case 13:
          if (!(process.argv[2] === '--install')) {
            _context.next = 17;
            break;
          }

          console.log('Installing new dependencies');
          _context.next = 17;
          return installDeps();

        case 17:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, this);
}))();

==> babel-upgrade-0.0.15.tgz: package/lib/bin.js <==
function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } } function _next(value) { step("next", value); } function _throw(err) { step("throw", err); } _next(); }); }; }

var path = require('path');

var _require = require('.'),
    isAcceptedNodeVersion = _require.isAcceptedNodeVersion,
    writePackageJSON = _require.writePackageJSON,
    writeBabelRC = _require.writeBabelRC,
    writeMochaOpts = _require.writeMochaOpts,
    installDeps = _require.installDeps;

var globby = require('globby');

if (!isAcceptedNodeVersion()) {
  throw new Error("Babel 7 will only support Node 4 and higher");
}

function hasFlow() {
  return _hasFlow.apply(this, arguments);
} // TOOD: allow passing a specific path


function _hasFlow() {
  _hasFlow = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee2() {
    var flowConfigs;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return globby(['**/.flowconfig', '!**/node_modules/**']);

          case 2:
            flowConfigs = _context2.sent;
            return _context2.abrupt("return", flowConfigs.length > 0);

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));
  return _hasFlow.apply(this, arguments);
}

_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee() {
  var paths, packages, mochaOpts, flow, upgradeOptions;
  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return globby(['**/.babelrc', '!**/node_modules/**']);

        case 2:
          paths = _context.sent;
          _context.next = 5;
          return globby(['**/package.json', '!**/node_modules/**']);

        case 5:
          packages = _context.sent;
          _context.next = 8;
          return globby(['**/mocha.opts', '!**/node_modules/**']);

        case 8:
          mochaOpts = _context.sent;
          _context.next = 11;
          return hasFlow();

        case 11:
          flow = _context.sent;
          upgradeOptions = {
            hasFlow: flow
          }; // if not a monorepo

          if (packages.length === 1) {
            if (paths.length > 1) {
              console.log("We suggest using the new 'overrides' option instead of nested .babelrc's, can check out http://new.babeljs.io/docs/en/next/babelrc.html#overrides");
              console.log("");
            }

            paths.forEach(function (p) {
              return writeBabelRC(p, upgradeOptions);
            });
          }

          mochaOpts.forEach(function (p) {
            return writeMochaOpts(p, upgradeOptions);
          }); // TOOD: allow passing a specific path

          _context.next = 17;
          return writePackageJSON(upgradeOptions);

        case 17:
          if (!(process.argv[2] === '--install')) {
            _context.next = 21;
            break;
          }

          console.log('Installing new dependencies');
          _context.next = 21;
          return installDeps();

        case 21:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, this);
}))();
